(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13500,        360]*)
(*NotebookOutlinePosition[     14445,        390]*)
(*  CellTagsIndexPosition[     14401,        386]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(\n (*RUNNING\ THE\ RIEMANN\ PROGRAM*) \)\)], "Input"],

Cell[TextData[{
  "(*This program calculates the Ricci rotation coefficients, Cartan \
connection forms, and Riemann, Ricci and Weyl curvature components in an \
orthonormal co-frame, \"orthoframe = ",
  Cell[BoxData[
      \(TraditionalForm\`{\ \[Theta]\_i\)]],
  "}\",  defined in terms of a set of coordinates. The space may have any \
dimension, and the orthonormal basis may have any \"signature\".*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*Select the first cell below and enter to bring up the program \
AVF. Then choose an output option, and then choose a calculation.*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(<< AVF.m;\)\)], "Input"],

Cell["\<\
(*If output=True, unsimplified results are printed as obtained; \
output= False specifies printing just a line of text describing what's being \
calculated at that time and a name for the results so they can be accessed at \
the end.*) \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(output = True\)], "Input"],

Cell[BoxData[
    \(output = False\)], "Input"],

Cell["\<\
(*To make a calculation, click in a titled cell below and enter. \
The calculation is finished when it prints \"Done\".
    The Simplify commands at the very end of the program can then be executed \
to see the results, which are presented as replacement rules obtained from \
Mathematica's Solve command. Unsimplified results can be displayed just by \
typing their names.
    A different case can be run by clicking in a new cell, with or without \
deleting the prior output. A different output option may be chosen if \
desired. All results from a prior calculation will be lost by executing \
another one.
    A new problem can be inserted by copying one of these problem cells and \
making the appropriate changes in \"signature\", \"makecoords\", \
\"tocoords\", and \"explicit\". For speed and economy, it is generally \
preferable to leave any complicated metric functions unspecified, and use \
\"explicit\" to replace them at the end. Errors can be caused by the Kernel \
remembering previous assignments; in that case it may be necessary to use the \
 Kernel: Quit Kernel menu command and to restart the program.*)\
\>", "Input",\

  FontFamily->"Times"],

Cell[BoxData[{
    \( (*Metric\ on\ a\ spheroid*) \n\nsignature = {1, 1}\), "\n", 
    \(makescalars[{}]; makecoords[{\[Theta], \[Phi]}]\), "\n", 
    \(tocoords = {\[Theta]\_1 -> 
          r0\ \(\@\(1 - k\ Sin[\[Theta]]^2\)\) d\[Theta], \[Theta]\_2 -> 
          r0\ \ Sin[\[Theta]] d\[Phi]}\), "\n", 
    \(\(explicit = {dummy -> dummy};\)\), "\n", 
    \(\ \(\(<< 
      orthoframes.m\)\(;\)\(Print["\<Done\>"]\)\(;\)\(\ \)\(\n\)\)\)}], \
"Input"],

Cell[BoxData[{
    \( (*Ruled\ surface\ taken\ from\ \(Eisenhart.\)*) \nsignature = {1, 1}\),
   
    \(makescalars[{u, v}]; makecoords[{u, v}]\), 
    \(tocoords
       = {\[Theta]\_1 -> du, 
        \[Theta]\_2 -> \(\@\(\((u - \[Alpha][v])\)^2 + \[Beta][v]^2\)\) dv}\),
   
    \(explicit = {dummy -> dummy}; \n\ << orthoframes.m; Print["\<Done\>"]; \ 
    \)}], "Input"],

Cell[BoxData[{
    \( (*Exterior\ Schwarzschild*) \n\nsignature = {1, 1, 1, \(-1\)}\), 
    \(makescalars[{}]; makecoords[{r, \[Theta], \[Phi], t}]\), 
    \(tocoords
       = {\[Theta]\_1 -> dr/\@\(1 - 2  m/r\), \[Theta]\_2 -> r\ \ d\[Theta], 
        \[Theta]\_3 -> r\ \ Sin[\[Theta]] d\[Phi], 
        \[Theta]\_4 -> \@\(1 - 2  m/r\)\ \ dt}\), 
    \(explicit = {dummy -> dummy}; \n\ << orthoframes.m; Print["\<Done\>"]; \ 
    \n\)}], "Input"],

Cell[BoxData[{
    \( (*Interior\ Schwarzschild*) \n\nsignature = {1, 1, 1, \(-1\)}\), 
    \(makescalars[{}]; makecoords[{r, \[Theta], \[Phi], t}]\), 
    \(tocoords
       = {\[Theta]\_1 -> dr/\@\(1 - 2  \[Rho]0\ r^2/3\), 
        \[Theta]\_2 -> r\ \ d\[Theta], 
        \[Theta]\_3 -> r\ \ Sin[\[Theta]] d\[Phi], 
        \[Theta]\_4 -> 
          \((3 \@\( 1 - 2  \[Rho]0\ R^2/3\) - \@\(1 - 2  \[Rho]0\ r^2/3\))
              \)\ \ dt}\), 
    \(explicit = {dummy -> dummy}; \n\ << orthoframes.m; Print["\<Done\>"]; \ 
    \n\)}], "Input"],

Cell[BoxData[{
    \( (*Robertson - Walker \((closed)\).The\ flat\ and\ open\ models\n
      can\ be\ obtained\ by\ changing "\<explicit\>"\ at\ the\ end\n
      and\ re - simplifying\ with\ \(it.\)*) \n\n
    signature = {1, 1, 1, \(-1\)}\), 
    \(makescalars[{}]; makecoords[{r, \[Theta], \[Phi], t}]\), 
    \(tocoords = \n
      \t{\[Theta]\_1 -> R[t] dr, \[Theta]\_2 -> R[t] S[r]\ d\[Theta], \n\t\t
        \[Theta]\_3 -> R[t] S[r]\ Sin[\[Theta]] d\[Phi], \[Theta]\_4 -> dt}\),
   
    \(explicit = {S -> Function[r, Sin[r]]}; \n\ << orthoframes.m; 
    Print["\<Done\>"]; \ \n\)}], "Input"],

Cell[BoxData[{
    \( (*\(Kerr\ metric\ in\ \*"\""spheroidal\) 
        \*"\"\< coordinates:~2 min\>."*) \n\nsignature = {1, 1, 1, \(-1\)}\), 
  
    \(makescalars[{}]; makecoords[{x, y, \[Phi], t}]\), 
    \(g = x^2 + y^2\), 
    \(\[CapitalPhi] = \@\(g/\((h1[x] - h2[y])\)\)\), 
    \(radius = \[Delta]\ r0\ \[CapitalPhi]\ \@\(h1[x]\ h2[y]\)\), 
    \(twist = 2\ \[Delta]\ \ m\ x\ h2[y]/\((h1[x] - h2[y])\)\), 
    \(tocoords
       = {\[Theta]\_1 -> r0\ \(\@\(g/h1[x]\)\) dx, 
        \[Theta]\_2 -> r0\ \(\@\(g/h2[y]\)\) dy, 
        \[Theta]\_3 -> radius\ d\[Phi], 
        \[Theta]\_4 -> \((dt - twist\ d\[Phi])\)/\[CapitalPhi]}\), 
    \(explicit
       = {h1 -> Function[x, 1 + x^2 - 2\ m\ x/r0], h2 -> Function[y, 1 - y^2]}
        \), 
    \(\ << orthoframes.m; Print["\<Done\>"]; \ \n\)}], "Input"],

Cell["\<\
(*The following is a case in which Mathematica's Simplify command \
will not achieve a useful result in a reasonable time, unless the option \
Trig->False is included, and even then may take quite a while. This option is \
usually used inside the 'orthoframes.m' calculation procedure to avoid \
wasting time, since Simplifying with the default Trig option (i.e., True) can \
always be tried later. After waiting several minutes without success, one may \
want to Abort the calculation, and try something else. Simplify does succeed \
on the matter tensor components, as illustrated by the 'riccicomps' \
command.*)  \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \( (*Solution\ for\ a\ rigidly\ rotating\ fluid\ \(body : \(\(~\)\(4\)\)\ \
\(\(min\)\(.\)\)\)*) \n\nsignature = {1, 1, 1, \(-1\)}\), "\n", 
    \(makescalars[{}]; makecoords[{u, v, \[Phi], t}]\), "\n", 
    \(g = Cos[2  u] + Cosh[2  v]\), "\n", 
    \(\[CapitalPhi] = \@\(\[Kappa]\ g/\((h1[u] - h2[v])\)\)\), "\n", 
    \(radius = 2\ r0\ \[CapitalPhi]\ \@\(h1[u]\ h2[v]\)\), "\n", 
    \(twist = 
      2  \[Kappa]\ r0 \((h1[u] \((Cosh[2  v] - Cosh[2  vA])\) + 
              h2[v] \((Cos[2  u] + Cosh[2  vA])\))\)/\((h1[u] - 
              h2[v])\)\), "\n", 
    \(tocoords = {\[Theta]\_1 -> \(\@\(\(g/h1[u]\)/\[Mu]0\)\) 
            du, \[Theta]\_2 -> \(\@\(\(g/h2[v]\)/\[Mu]0\)\) dv, \[Theta]\_3 -> 
          radius\ d\[Phi], \[Theta]\_4 -> \ \((\ 
              dt - twist\ d\[Phi])\)/\[CapitalPhi]}\), "\n", 
    \(explicit = {h1 -> 
          Function[u, h0 + e0\ Cos[2\ u] + \((u + u0)\) Sin[2  u]], 
        h2 -> Function[v, 
            h0 - e0\ Cosh[2  v] + \((v + v0)\) Sinh[2  v]]}\), "\n", 
    \(\ \(\(<< 
      orthoframes.m\)\(;\)\(Print["\<Done\>"]\)\(;\)\(\ \)\(\n\)\)\)}], \
"Input"],

Cell[BoxData[{
    \( (*P - P\ gravity\ wave . \ Null\ coordinates\ {u, v}\ defined\ by\ u = 
        t - z, v = t + \(\(z\)\(.\)\)*) \n\n
    signature = {1, 1, 1, \(-1\)}\), "\n", 
    \(makescalars[{u, v, x, y}]\), "\n", 
    \(tocoords = {\[Theta]\_1 \[Rule] L[u] \(E\^\[Beta][u]\) dx, \[Theta]\_2 -> 
          L[u] \(E\^\(-\[Beta][u]\)\) dy, \[Theta]\_3 \[Rule] 
          dv/2 - du/2, \[Theta]\_4 -> dv/2 + du/2}\), "\n", 
    \(metric = 
      Expand[\((\[Theta]\_1\^2 + \[Theta]\_2\^2 + \[Theta]\_3\^2 - \
\[Theta]\_4\^2)\) /. tocoords]\), "\[IndentingNewLine]", 
    \(\(explicit = {dummy -> dummy};\)\), "\n", 
    \(\ \(\(<< 
      orthoframes.m\)\(;\)\(Print["\<Done\>"]\)\(;\)\(\ \)\(\n\)\)\)}], \
"Input"],

Cell[BoxData[
    \(\n\)], "Input"],

Cell[BoxData[
    \(\( (*SIMPLIFIED\ RESULTS*) \n\)\)], "Input"],

Cell["\<\
(*To display results execute the commands below. In complicated \
problems they may take a minute or two, even with the option Trig->False.*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(res1 = Simplify[rotationcomps /. explicit]\)], "Input"],

Cell[BoxData[
    \(res1 = Simplify[rotationcomps /. explicit, Trig -> False]\)], "Input"],

Cell[BoxData[
    \(res2 = Simplify[riemanncomps /. explicit]\)], "Input"],

Cell[BoxData[
    \(res2 = Simplify[riemanncomps /. explicit, Trig -> False]\)], "Input"],

Cell[BoxData[
    \(res3 = Simplify[riccicomps /. explicit]\)], "Input"],

Cell[BoxData[
    \(res3 = Simplify[riccicomps /. explicit, Trig -> False]\)], "Input"],

Cell[BoxData[
    \(res4 = Simplify[ricciscalar /. explicit]\)], "Input"],

Cell[BoxData[
    \(res5 = Simplify[weylcomps /. explicit]\)], "Input"],

Cell[BoxData[
    \(res5 = Simplify[weylcomps /. explicit, Trig -> False]\)], "Input"],

Cell[TextData[{
  "\n(*In 4-dim. spacetimes, the timelike vector dual to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_4\)]],
  "is often a preferred vector field.\nThe 3-space components of the \
acceleration, a , angular velocity, \[CapitalOmega] , and rate-of-strain, S , \
of this timelike congruence are given in the \"dyadics\" list.*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(res6 = Simplify[dyadics /. res1]\)], "Input"],

Cell[BoxData[
    \(res6 = Simplify[dyadics /. res1, Trig -> False]\)], "Input"],

Cell[TextData[{
  "(*In the local rest-frame of this congruence, the components of the \
stress-energy\ntensor are given in the \"stress\" list. The symbols are: \
\[Rho] = energy density,\np = pressure, \[Mu] = \[Rho] + 3 p ,  t = momentum \
density 3-vector, and M = T +p I,\nthe anisotropic stress dyadic with TrM = \
0. Units are  ",
  Cell[BoxData[
      \(TraditionalForm\`4  \[Pi]\ G/c\^2\)]],
  " = 1 .*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(res7 = Simplify[stress /. res3]\)], "Input"],

Cell[BoxData[
    \(res7 = Simplify[stress /. res3, Trig -> False]\)], "Input"],

Cell[BoxData[
    \(Simplify[%]\)], "Input"],

Cell["\<\
(*The \"electric\", A , and \"magnetic\", B , components of the \
Weyl tensor in the same rest-frame are given in the \"AB\" list. Both A and B \
are symmetric, traceless, dyadics. The complex matrix, Q = A+i B.*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(res8 = Simplify[AB /. res5]\)], "Input"],

Cell[BoxData[
    \(res8 = Simplify[AB /. res5, Trig -> False]\)], "Input"],

Cell[BoxData[
    \(Q = Q /. res8\)], "Input"],

Cell[BoxData[
    \(lambdas = Simplify[Eigenvalues[Q]]\)], "Input"],

Cell[BoxData[""], "Input"],

Cell["\<\
(*Some special massaging is required for the lambdas of the Kerr \
solution.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(kerrsimps1
       = {\@\(\((1 - \(2\ m\ x\)\/r0 + x\^2)\)\ \((1 - y\^2)\)\)\ 
            \@\(\(r0\ \((x\^2 + y\^2)\)\)\/\(r0 - 2\ m\ x + r0\ x\^2\)\)\ 
            \@\(\(x\^2 + y\^2\)\/\(1 - y\^2\)\) \[Rule] x\^2 + y\^2, 
        \@\(-\(\(\((r0 - 2\ m\ x + r0\ x\^2)\)\ \((\(-1\) + y\^2)\)\)\/r0
                    \)\)\ \@\(\(r0\ \((x\^2 + y\^2)\)\)\/\(r0 - 2\ m\ x + 
                    r0\ x\^2\)\)\ 
            \@\(\(-\(x\^2 + y\^2\)\)\/\(\(-1\) + y\^2\)\) \[Rule] 
          x\^2 + y\^2}; 
    kerrsimps2
       = {\ x\^2 + y\^2 \[Rule] \((x - I\ y)\)\ \((x + I\ y)\), 
        \@\(m\^2\ r0\^6\ \((x - I\ y)\)\^14\ \((x + I\ y)\)\^8\) \[Rule] 
          m\ r0\^3\ \((x - I\ y)\)\^7\ \((x + I\ y)\)\^4}; \n
    Simplify[lambdas /. kerrsimps1] //. kerrsimps2\)], "Input"]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
NotebookAutoSave->False,
AutoGeneratedPackage->Automatic,
WindowSize->{648, 507},
WindowMargins->{{13, Automatic}, {Automatic, 6}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@D<][0000000000060801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 75, 1, 43, "Input"],
Cell[1783, 53, 442, 9, 60, "Input"],
Cell[2228, 64, 183, 5, 44, "Input"],
Cell[2414, 71, 46, 1, 27, "Input"],
Cell[2463, 74, 284, 6, 60, "Input"],
Cell[2750, 82, 46, 1, 27, "Input"],
Cell[2799, 85, 47, 1, 27, "Input"],
Cell[2849, 88, 1175, 20, 220, "Input"],
Cell[4027, 110, 451, 9, 146, "Input"],
Cell[4481, 121, 373, 9, 130, "Input"],
Cell[4857, 132, 447, 8, 169, "Input"],
Cell[5307, 142, 543, 11, 169, "Input"],
Cell[5853, 155, 597, 11, 203, "Input"],
Cell[6453, 168, 809, 17, 238, "Input"],
Cell[7265, 187, 665, 11, 108, "Input"],
Cell[7933, 200, 1124, 21, 286, "Input"],
Cell[9060, 223, 720, 14, 199, "Input"],
Cell[9783, 239, 35, 1, 43, "Input"],
Cell[9821, 242, 64, 1, 43, "Input"],
Cell[9888, 245, 191, 5, 44, "Input"],
Cell[10082, 252, 75, 1, 27, "Input"],
Cell[10160, 255, 90, 1, 27, "Input"],
Cell[10253, 258, 74, 1, 27, "Input"],
Cell[10330, 261, 89, 1, 27, "Input"],
Cell[10422, 264, 72, 1, 27, "Input"],
Cell[10497, 267, 87, 1, 27, "Input"],
Cell[10587, 270, 73, 1, 27, "Input"],
Cell[10663, 273, 71, 1, 27, "Input"],
Cell[10737, 276, 86, 1, 27, "Input"],
Cell[10826, 279, 386, 8, 76, "Input"],
Cell[11215, 289, 65, 1, 27, "Input"],
Cell[11283, 292, 80, 1, 27, "Input"],
Cell[11366, 295, 449, 10, 76, "Input"],
Cell[11818, 307, 64, 1, 27, "Input"],
Cell[11885, 310, 79, 1, 27, "Input"],
Cell[11967, 313, 44, 1, 27, "Input"],
Cell[12014, 316, 263, 6, 44, "Input"],
Cell[12280, 324, 60, 1, 27, "Input"],
Cell[12343, 327, 75, 1, 27, "Input"],
Cell[12421, 330, 46, 1, 27, "Input"],
Cell[12470, 333, 67, 1, 27, "Input"],
Cell[12540, 336, 26, 0, 27, "Input"],
Cell[12569, 338, 126, 4, 28, "Input"],
Cell[12698, 344, 798, 14, 189, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

